# Changelog


### 0.3.0.dev4 (05/04/2023)
* Finished instant_setup().
* Changed the way a secret key is generated, to make it more safe and efficient.
* Fixed incorrect date in changelog (0.3.0.dev3 was released 09/12/2022, not 02/12/2022).
* Updated README to make it clearer and to reflect new changes.


### 0.3.0.dev3 (09/12/2022)
* Worked on instant_setup().


### 0.3.0.dev2 (02/12/2022)
* Fixed major parts of the module not getting downloaded using pip despite being in the tar.gz.


### 0.3.0.dev1 (02/12/2022)
* Started working on instant_setup, a function for instantly settings up a webpage without any arguments.
* Made a few tweaks to some of the functions and changed up the directory structure a bit.

### 0.2.0 (01/12/2022)
* Fixed up a lot of smaller bugs in the code, and fixed the warnings not making any sense.


### 0.1.2 (01/12/2022)
* Made _basic and _models subpackages since normal directories don't get uploaded.


### 0.1.1 (01/12/2022)
* Added *.md in global-include because I forgot to...


### 0.1.0 (01/12/2022)
* First Release
